; Emulation of SC/MP on a PIC16F877 with NIBL
;
; (c) 2019 K Orton
;
; PORTA is SC/MP flags as per status register:
;
;	0 F0 (NIBL: TxD)
;	1 F1 (NIBL: Reader relay /RTS)
;	2 F2
;	3 F3*
;	4 SA
;	5 SB (NIBL: RxD)
;
;	* Actually, SC/MP IE status
;	  (available as fourth flag)
;
; PORTB is D0..D7
;
; PORTC is A0..A7
;
; PORTD is A8..A15
;
; PORTE is memory control:
;
;	0  NRDS
;	1  NWDS
;	2  Reserved (input)
;
; PIC clock frequency:
;
;	10MHz for 2MHz SC/MP
;	20MHz for 4MHz SC/MP
;
; NIBL interpreter is copied to RAM 0000..0FFF
;
; NIBL code is then write protected
;
; Sense A interrupts are not supported
;
; SIN and SOUT not supported
;
; SIO instruction shifts right extension ('SRE') 

; PIC constants
W	EQU	0
INDF	EQU	H'0000'
PCL	EQU	H'0002'
STATUS	EQU	H'0003'
FSR	EQU	H'0004'
PORTA	EQU	H'0005'
PORTB	EQU	H'0006'
PORTC	EQU	H'0007'
PORTD	EQU	H'0008'
PORTE	EQU	H'0009'
PCLATH	EQU	H'000A'
TRISA	EQU	H'0085'
TRISB	EQU	H'0086'
TRISC	EQU	H'0087'
TRISD	EQU	H'0088'
TRISE	EQU	H'0089'
ADCON1	EQU	H'009F'
EEDATA	EQU	H'010C'
EEADR	EQU	H'010D'
EEADRH	EQU	H'010F'
EECON1	EQU	H'018C'
C	EQU	0
DC	EQU	1
Z	EQU	2
RP0	EQU	5
RP1	EQU	6
RD	EQU	0
PGD	EQU	7
CFG	EQU	H'3D32'

	__CONFIG	CFG

; Program constants
; Registers 32..95 in every bank are used
;  to hold RAM image (total 256 bytes)
ACC	EQU	H'70'
EXT	EQU	H'71'
STAT	EQU	H'72'
P0HI	EQU	H'73'
P0LO	EQU	H'74'
P1HI	EQU	H'75'
P1LO	EQU	H'76'
P2HI	EQU	H'77'
P2LO	EQU	H'78'
P3HI	EQU	H'79'
P3LO	EQU	H'7A'
OPRND	EQU	H'7B'
EAHI	EQU	H'7C'
EALO	EQU	H'7D'
DATUM	EQU	H'7E'
TMP	EQU	H'7F'
IE	EQU	3
OV	EQU	6
CYL	EQU	7
NRDS	EQU	0
NWDS	EQU	1

; Read RAM macro (10)
; Read data returned in W
RDRAM	MACRO	PHI,PLO
	MOVF	PHI,W
	MOVWF	PORTD
	MOVF	PLO,W
	MOVWF	PORTC
	MOVLW	B'11111111'
	MOVWF	INDF
	BCF	PORTE,NRDS
	NOP
	MOVF	PORTB,W
	BSF	PORTE,NRDS
	ENDM

; Long jump to home page macro (4)
HOME	MACRO	DST
	MOVLW	HIGH(OPVEC)
	MOVWF	PCLATH
	GOTO	DST
	ENDM

; Long jump to page 0 macro (3)
LJMP0	MACRO	DST
	CLRF	PCLATH
	GOTO	DST
	ENDM

; Exchange byte macro (6)
XCHNG	MACRO	A,B
	MOVF	A,W
	MOVWF	TMP
	MOVF	B,W
	MOVWF	A
	MOVF	TMP,W
	MOVWF	B
	ENDM

; Binary add macro (16)
ADD	MACRO	SCE
	MOVF	SCE,W
	XORWF	ACC,W
	XORLW	H'80'
	MOVWF	TMP
	BTFSC	STAT,CYL
	INCFSZ	ACC
	BCF	STAT,CYL
	MOVF	SCE,W
	ADDWF	ACC
	BTFSC	STATUS,C
	BSF	STAT,CYL
	XORWF	ACC,W
	ANDWF	TMP
	BCF	STAT,OV
	BTFSC	TMP,7
	BSF	STAT,OV
	ENDM

; Decimal add macro (14)
DAD	MACRO	SCE
	MOVLW	H'66'
	ADDWF	SCE
	BTFSC	STAT,CYL
	INCF	ACC
	RLF	STAT
	MOVF	SCE,W
	ADDWF	ACC
	RRF	STAT
	MOVLW	H'06'
	BTFSS	STATUS,DC
	SUBWF	ACC
	MOVLW	H'60'
	BTFSS	STAT,CYL
	SUBWF	ACC
	ENDM

; Increment PC macro (3)
INCPC	MACRO
	INCF	P0HI
	INCFSZ	P0LO
	DECF	P0HI
	ENDM

; Get operand macro (17)
; Operand returned in OPRND and W
GOP	MACRO
	INCPC
	RDRAM	P0HI,P0LO
	MOVWF	OPRND
	NOP
	NOP
	NOP
	ENDM

; Get effective address macro (15)
; Operand expected in OPRND and W
; Effective address returned in EAHI, EALO
GEA	MACRO	PHI,PLO
	LOCAL	L1
	LOCAL	L2
	XORLW	H'80'
	BTFSC	STATUS,Z
	GOTO	L1
	NOP
	GOTO	L2
L1	MOVF	EXT,W
	MOVWF	OPRND
L2	MOVF	PHI,W
	MOVWF	EAHI
	BTFSC	OPRND,7
	DECF	EAHI
	MOVF	OPRND,W
	ADDWF	PLO,W
	MOVWF	EALO
	BTFSC	STATUS,C
	INCF	EAHI
	ENDM

; Effective address to PC macro (32)
; For home page use only
; Exits directly to EXEC
GEAPC	MACRO	PHI,PLO
	GOP
	MOVF	PHI,W
	MOVWF	P0HI
	BTFSC	OPRND,7
	DECF	P0HI
	MOVF	OPRND,W
	ADDWF	PLO,W
	MOVWF	P0LO
	BTFSC	STATUS,C
	INCF	P0HI
	NOP
	NOP
	NOP
	NOP
	GOTO	EXEC
	ENDM

; Read memory macro (18)
; Read data returned in DATUM and W
RDMEM	MACRO	PHI,PLO
	RDRAM	PHI,PLO
	MOVWF	DATUM
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	ENDM

; Auto indexed read memory macro (59)
; For home page use only
; Read data returned in DATUM and W
RDMEMA	MACRO	PHI,PLO
	LOCAL	L1
	LOCAL	L2
	GOP
	GEA	PHI,PLO
	BTFSC	OPRND,7
	GOTO	L1
	RDMEM	PHI,PLO
	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	MOVF	DATUM,W
	GOTO	L2
L1	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	RDMEM	PHI,PLO
	NOP
	NOP
L2
	ENDM

; Auto indexed add memory macro (76)
; For home page use only
; Exits directly to EXEC
ADMEMA	MACRO	PHI,PLO
	LOCAL	L1
	GOP
	GEA	PHI,PLO
	NOP
	BTFSC	OPRND,7
	GOTO	L1
	NOP
	RDMEM	PHI,PLO
	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	ADD	DATUM
	GOTO	EXEC
L1	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	RDMEM	PHI,PLO
	ADD	DATUM
	GOTO	EXEC
	ENDM

; Write memory macro (22)
; For page 0 use only
WRMEM	MACRO	PHI,PLO
	LOCAL	L1
	LOCAL	L2
	MOVF	PHI,W
	ANDLW	B'11110000'
	BTFSC	STATUS,Z
	GOTO	L1
	MOVF	PHI,W
	MOVWF	PORTD
	MOVF	PLO,W
	MOVWF	PORTC
	CLRF	INDF
	MOVF	ACC,W
	MOVWF	PORTB
	NOP
	BCF	PORTE,NWDS
	NOP
	BSF	PORTE,NWDS
	GOTO	L2
L1	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
L2	NOP
	NOP
	NOP
	RETURN
	ENDM

; Auto indexed write memory macro (68)
; For page 0 use only
; Exits directly to EXEC
WRMEMA	MACRO	PHI,PLO,WRSUB
	LOCAL	L1
	GOP
	GEA	PHI,PLO
	BTFSC	OPRND,7
	GOTO	L1
	CALL	WRSUB
	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	HOME	PAD2
L1	MOVF	EAHI,W
	MOVWF	PHI
	MOVF	EALO,W
	MOVWF	PLO
	CALL	WRSUB
	NOP
	HOME	EXEC
	ENDM

; PIC reset
	ORG	0
	MOVLW	B'00000011'
	MOVWF	PORTE
	BSF	STATUS,RP0
	MOVLW	B'00000110'
	MOVWF	ADCON1
	MOVLW	B'00110000'
	MOVWF	TRISA
	CLRF	TRISC
	CLRF	TRISD
	MOVLW	B'00000100'
	MOVWF	TRISE
	BCF	STATUS,RP0
	MOVLW	TRISB
	MOVWF	FSR

; SC/MP reset
RESET	CLRF	ACC
	CLRF	EXT
	CLRF	STAT
	CLRF	P0HI
	CLRF	P0LO
	CLRF	P1HI
	CLRF	P1LO
	CLRF	P2HI
	CLRF	P2LO
	CLRF	P3HI
	CLRF	P3LO
	CLRF	PORTA

; Load NIBL to RAM
	CLRF	PORTC
	CLRF	PORTD
	CLRF	INDF
	BSF	STATUS,RP1
	MOVLW	LOW(NIBL)
	MOVWF	EEADR
	MOVLW	HIGH(NIBL)
	MOVWF	EEADRH
	BCF	STATUS,RP1
L1	BSF	STATUS,RP1
	BSF	STATUS,RP0
	BSF	EECON1,PGD
	BSF	EECON1,RD
	NOP
	NOP
	BCF	STATUS,RP0
	INCF	EEADRH
	INCFSZ	EEADR
	DECF	EEADRH
	MOVF	EEDATA,W
	CLRF	STATUS
	MOVWF	PORTB
	NOP
	BCF	PORTE,NWDS
	NOP
	BSF	PORTE,NWDS
	NOP
	INCF	PORTD
	INCFSZ	PORTC
	DECF	PORTD
	BTFSS	PORTD,4
	GOTO	L1
	HOME	EXEC

; Opcode functions
XAEX	XCHNG	ACC,EXT
	HOME	PAD3
XPAL0X	XCHNG	ACC,P0LO
	HOME	PAD8
XPAL1X	XCHNG	ACC,P1LO
	HOME	PAD8
XPAL2X	XCHNG	ACC,P2LO
	HOME	PAD8
XPAL3X	XCHNG	ACC,P3LO
	HOME	PAD8
XPAH0X	XCHNG	ACC,P0HI
	HOME	PAD8
XPAH1X	XCHNG	ACC,P1HI
	HOME	PAD8
XPAH2X	XCHNG	ACC,P2HI
	HOME	PAD8
XPAH3X	XCHNG	ACC,P3HI
	HOME	PAD8
LD0X	CALL	RD0X
	MOVWF	ACC
	HOME	PAD9
LD1X	CALL	RD1X
	MOVWF	ACC
	HOME	PAD9
LD2X	CALL	RD2X
	MOVWF	ACC
	HOME	PAD9
LD3X	CALL	RD3X
	MOVWF	ACC
	HOME	PAD9
ADD0X	GOP
	GEA	P0HI,P0LO
	RDMEM	EAHI,EALO
	ADD	DATUM
	HOME	PAD3
ADD1X	GOP
	GEA	P1HI,P1LO
	RDMEM	EAHI,EALO
	ADD	DATUM
	HOME	PAD3
ADD2X	GOP
	GEA	P2HI,P2LO
	RDMEM	EAHI,EALO
	ADD	DATUM
	HOME	PAD3
ADD3X	GOP
	GEA	P3HI,P3LO
	RDMEM	EAHI,EALO
	ADD	DATUM
	HOME	PAD3
CAD0X	CALL	RD0X
	COMF	DATUM
	ADD	DATUM
	HOME	PAD3
CAD1X	CALL	RD1X
	COMF	DATUM
	ADD	DATUM
	HOME	PAD3
CAD2X	CALL	RD2X
	COMF	DATUM
	ADD	DATUM
	HOME	PAD3
CAD3X	CALL	RD3X
	COMF	DATUM
	ADD	DATUM
	HOME	PAD3
AND0X	CALL	RD0X
	ANDWF	ACC
	HOME	PAD9
AND1X	CALL	RD1X
	ANDWF	ACC
	HOME	PAD9
AND2X	CALL	RD2X
	ANDWF	ACC
	HOME	PAD9
AND3X	CALL	RD3X
	ANDWF	ACC
	HOME	PAD9
OR0X	CALL	RD0X
	IORWF	ACC
	HOME	PAD9
OR1X	CALL	RD1X
	IORWF	ACC
	HOME	PAD9
OR2X	CALL	RD2X
	IORWF	ACC
	HOME	PAD9
OR3X	CALL	RD3X
	IORWF	ACC
	HOME	PAD9
XOR0X	CALL	RD0X
	XORWF	ACC
	HOME	PAD9
XOR1X	CALL	RD1X
	XORWF	ACC
	HOME	PAD9
XOR2X	CALL	RD2X
	XORWF	ACC
	HOME	PAD9
XOR3X	CALL	RD3X
	XORWF	ACC
	HOME	PAD9
DAD0X	CALL	RD0X
	CALL	DADDX
	HOME	PAD17
DAD1X	CALL	RD1X
	CALL	DADDX
	HOME	PAD17
DAD2X	CALL	RD2X
	CALL	DADDX
	HOME	PAD17
DAD3X	CALL	RD3X
	CALL	DADDX
	HOME	PAD17
LDIX	CALL	GOPX
	MOVWF	ACC
	HOME	PAD2
ANIX	GOP
	ANDWF	ACC
	HOME	PAD6
ORIX	CALL	GOPX
	IORWF	ACC
	HOME	PAD2
XRIX	CALL	GOPX
	XORWF	ACC
	HOME	PAD2
DAEX	DAD	EXT
	HOME	PAD15
DAIX	CALL	GOPX
	DAD	OPRND
	HOME	PAD14
CAIX	GOP
	COMF	OPRND
	ADD	OPRND
	HOME	EXEC
ILD0X	CALL	RD0X
	ADDLW	1
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
ILD1X	CALL	RD1X
	ADDLW	1
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
ILD2X	CALL	RD2X
	ADDLW	1
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
ILD3X	CALL	RD3X
	ADDLW	1
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
DLD0X	CALL	RD0X
	ADDLW	H'FF'
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
DLD1X	CALL	RD1X
	ADDLW	H'FF'
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
DLD2X	CALL	RD2X
	ADDLW	H'FF'
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
DLD3X	CALL	RD3X
	ADDLW	H'FF'
	MOVWF	ACC
	CALL	WREAX
	HOME	PAD4
ST0X	CALL	EA0X
	CALL	WREAX
	HOME	EXEC
ST1X	CALL	EA1X
	CALL	WREAX
	HOME	EXEC
ST2X	CALL	EA2X
	CALL	WREAX
	HOME	EXEC
ST3X	CALL	EA3X
	CALL	WREAX
	HOME	EXEC
ST1AX	WRMEMA	P1HI,P1LO,WR1X
ST2AX	WRMEMA	P2HI,P2LO,WR2X
ST3AX	WRMEMA	P3HI,P3LO,WR3X
DLYX	CALL	GOPX
	MOVF	ACC
	BTFSC	STATUS,Z
	GOTO	L16
	NOP
	NOP
L15	NOP
	NOP
	NOP
	CALL	DEL4X
	DECFSZ	ACC
	GOTO	L15
L16	MOVF	OPRND
	BTFSC	STATUS,Z
	GOTO	L19
	NOP
	NOP
L17	NOP
	NOP
	NOP
	MOVLW	H'E9'
	MOVWF	TMP
L18	CALL	DEL4X
	CALL	DEL4X
	DECFSZ	TMP
	GOTO	L18
	DECFSZ	OPRND
	GOTO	L17
L19	DECF	ACC
	HOME	PAD9

; Page 0 opcode support
GOPX	GOP
DEL4X	RETURN
RD0X	GOP
	GEA	P0HI,P0LO
	RDMEM	EAHI,EALO
	RETURN
RD1X	GOP
	GEA	P1HI,P1LO
	RDMEM	EAHI,EALO
	RETURN
RD2X	GOP
	GEA	P2HI,P2LO
	RDMEM	EAHI,EALO
	RETURN
RD3X	GOP
	GEA	P3HI,P3LO
	RDMEM	EAHI,EALO
	RETURN
DADDX	DAD	DATUM
	RETURN
EA0X	CALL	GOPX
	GEA	P0HI,P0LO
	RETURN
EA1X	CALL	GOPX
	GEA	P1HI,P1LO
	RETURN
EA2X	CALL	GOPX
	GEA	P2HI,P2LO
	RETURN
EA3X	CALL	GOPX
	GEA	P3HI,P3LO
	RETURN
WREAX	WRMEM	EAHI,EALO
WR1X	WRMEM	P1HI,P1LO
WR2X	WRMEM	P2HI,P2LO
WR3X	WRMEM	P3HI,P3LO

; Page 1 - main emulation kernel (home page)
	ORG	H'0800'

; Opcode vector table
OPVEC	GOTO	XHALT	; 00 HALT    8~
	GOTO	XAE	; 01 XAE     7~
	GOTO	CCL	; 02 CCL     5~
	GOTO	SCL	; 03 SCL     5~
	GOTO	DINT	; 04 DINT    6~
	GOTO	IEN	; 05 IEN     6~
	GOTO	CSA	; 06 CSA     5~
	GOTO	CAS	; 07 CAS     6~
	GOTO	XNOP	; 08 NOP     5~
	GOTO	ILL	; 09
	GOTO	ILL	; 0A
	GOTO	ILL	; 0B
	GOTO	ILL	; 0C
	GOTO	ILL	; 0D
	GOTO	ILL	; 0E
	GOTO	ILL	; 0F
	GOTO	ILL	; 10
	GOTO	ILL	; 11
	GOTO	ILL	; 12
	GOTO	ILL	; 13
	GOTO	ILL	; 14
	GOTO	ILL	; 15
	GOTO	ILL	; 16
	GOTO	ILL	; 17
	GOTO	ILL	; 18
	GOTO	SIO	; 19 SIO     5~
	GOTO	ILL	; 1A
	GOTO	ILL	; 1B
	GOTO	SR	; 1C SR      5~  
	GOTO	SRL	; 1D SRL     5~
	GOTO	RR	; 1E RR      5~
	GOTO	RRL	; 1F RRL     5~
	GOTO	ILL	; 20
	GOTO	ILL	; 21
	GOTO	ILL	; 22
	GOTO	ILL	; 23
	GOTO	ILL	; 24
	GOTO	ILL	; 25
	GOTO	ILL	; 26
	GOTO	ILL	; 27
	GOTO	ILL	; 28
	GOTO	ILL	; 29
	GOTO	ILL	; 2A
	GOTO	ILL	; 2B
	GOTO	ILL	; 2C
	GOTO	ILL	; 2D
	GOTO	ILL	; 2E
	GOTO	ILL	; 2F
	GOTO	XPAL0	; 30 XPAL0   8~
	GOTO	XPAL1	; 31 XPAL1   8~  
	GOTO	XPAL2	; 32 XPAL2   8~
	GOTO	XPAL3	; 33 XPAL3   8~ 
	GOTO	XPAH0	; 34 XPAH0   8~
	GOTO	XPAH1	; 35 XPAH1   8~
	GOTO	XPAH2	; 36 XPAH2   8~
	GOTO	XPAH3	; 37 XPAH3   8~
	GOTO	ILL	; 38
	GOTO	ILL	; 39
	GOTO	ILL	; 3A
	GOTO	ILL	; 3B
	GOTO	XPPC0	; 3C XPPC0   7~
	GOTO	XPPC1	; 3D XPPC1   7~
	GOTO	XPPC2	; 3E XPPC2   7~
	GOTO	XPPC3	; 3F XPPC3   7~
	GOTO	LDE	; 40 LDE     6~
	GOTO	ILL	; 41
	GOTO	ILL	; 42
	GOTO	ILL	; 43
	GOTO	ILL	; 44
	GOTO	ILL	; 45
	GOTO	ILL	; 46
	GOTO	ILL	; 47
	GOTO	ILL	; 48
	GOTO	ILL	; 49
	GOTO	ILL	; 4A
	GOTO	ILL	; 4B
	GOTO	ILL	; 4C
	GOTO	ILL	; 4D
	GOTO	ILL	; 4E
	GOTO	ILL	; 4F
	GOTO	ANE	; 50 ANE     6~
	GOTO	ILL	; 51
	GOTO	ILL	; 52
	GOTO	ILL	; 53
	GOTO	ILL	; 54
	GOTO	ILL	; 55
	GOTO	ILL	; 56
	GOTO	ILL	; 57
	GOTO	ORE	; 58 ORE     6~
	GOTO	ILL	; 59
	GOTO	ILL	; 5A
	GOTO	ILL	; 5B
	GOTO	ILL	; 5C
	GOTO	ILL	; 5D
	GOTO	ILL	; 5E
	GOTO	ILL	; 5F
	GOTO	XRE	; 60 XRE     6~
	GOTO	ILL	; 61
	GOTO	ILL	; 62
	GOTO	ILL	; 63
	GOTO	ILL	; 64
	GOTO	ILL	; 65
	GOTO	ILL	; 66
	GOTO	ILL	; 67
	GOTO	DAE	; 68 DAE     11~
	GOTO	ILL	; 69
	GOTO	ILL	; 6A
	GOTO	ILL	; 6B
	GOTO	ILL	; 6C
	GOTO	ILL	; 6D
	GOTO	ILL	; 6E
	GOTO	ILL	; 6F
	GOTO	ADE	; 70 ADE     7~
	GOTO	ILL	; 71
	GOTO	ILL	; 72
	GOTO	ILL	; 73
	GOTO	ILL	; 74
	GOTO	ILL	; 75
	GOTO	ILL	; 76
	GOTO	ILL	; 77
	GOTO	CAE	; 78 CAE     8~
	GOTO	ILL	; 79
	GOTO	ILL	; 7A
	GOTO	ILL	; 7B
	GOTO	ILL	; 7C
	GOTO	ILL	; 7D
	GOTO	ILL	; 7E
	GOTO	ILL	; 7F
	GOTO	ILL	; 80
	GOTO	ILL	; 81
	GOTO	ILL	; 82
	GOTO	ILL	; 83
	GOTO	ILL	; 84
	GOTO	ILL	; 85
	GOTO	ILL	; 86
	GOTO	ILL	; 87
	GOTO	ILL	; 88
	GOTO	ILL	; 89
	GOTO	ILL	; 8A
	GOTO	ILL	; 8B
	GOTO	ILL	; 8C
	GOTO	ILL	; 8D
	GOTO	ILL	; 8E
	GOTO	DLY	; 8F DLY     13-131593~
	GOTO	JMP0	; 90 JMP0    11~
	GOTO	JMP1	; 91 JMP1    11~
	GOTO	JMP2	; 92 JMP2    11~
	GOTO	JMP3	; 93 JMP3    11~
	GOTO	JP0	; 94 JP0     9/11~
	GOTO	JP1	; 95 JP1     9/11~
	GOTO	JP2	; 96 JP2     9/11~
	GOTO	JP3	; 97 JP3     9/11~
	GOTO	JZ0	; 98 JZ0     9/11~
	GOTO	JZ1	; 99 JZ1     9/11~
	GOTO	JZ2	; 9A JZ2     9/11~
	GOTO	JZ3	; 9B JZ3     9/11~
	GOTO	JNZ0	; 9C JNZ0    9/11~
	GOTO	JNZ1	; 9D JNZ1    9/11~
	GOTO	JNZ2	; 9E JNZ2    9/11~
	GOTO	JNZ3	; 9F JNZ3    9/11~
	GOTO	ILL	; A0	
	GOTO	ILL	; A1
	GOTO	ILL	; A2
	GOTO	ILL	; A3
	GOTO	ILL	; A4
	GOTO	ILL	; A5
	GOTO	ILL	; A6
	GOTO	ILL	; A7
	GOTO	ILD0	; A8 ILD0    22~
	GOTO	ILD1	; A9 ILD1    22~
	GOTO	ILD2	; AA ILD2    22~
	GOTO	ILD3	; AB ILD3    22~
	GOTO	ILL	; AC
	GOTO	ILL	; AD
	GOTO	ILL	; AE
	GOTO	ILL	; AF
	GOTO	ILL	; B0
	GOTO	ILL	; B1
	GOTO	ILL	; B2
	GOTO	ILL	; B3
	GOTO	ILL	; B4
	GOTO	ILL	; B5
	GOTO	ILL	; B6
	GOTO	ILL	; B7
	GOTO	DLD0	; B8 DLD0    22~
	GOTO	DLD1	; B9 DLD1    22~
	GOTO	DLD2	; BA DLD2    22~
	GOTO	DLD3	; BB DLD3    22~
	GOTO	ILL	; BC
	GOTO	ILL	; BD
	GOTO	ILL	; BE
	GOTO	ILL	; BF
	GOTO	LD0	; C0 LD(0)   18~
	GOTO	LD1	; C1 LD(1)   18~
	GOTO	LD2	; C2 LD(2)   18~
	GOTO	LD3	; C3 LD(3)   18~
	GOTO	LDI	; C4 LDI     10~
	GOTO	LD1A	; C5 LD@(1)  18~
	GOTO	LD2A	; C6 LD@(2)  18~
	GOTO	LD3A	; C7 LD@(3)  18~
	GOTO	ST0	; C8 ST(0)   18~
	GOTO	ST1	; C9 ST(1)   18~
	GOTO	ST2	; CA ST(2)   18~
	GOTO	ST3	; CB ST(3)   18~
	GOTO	ILL	; CC
	GOTO	ST1A	; CD ST@(1)  18~
	GOTO	ST2A	; CE ST@(2)  18~
	GOTO	ST3A	; CF ST@(3)  18~  
	GOTO	AND0	; D0 AND(0)  18~
	GOTO	AND1	; D1 AND(1)  18~
	GOTO	AND2	; D2 AND(2)  18~
	GOTO	AND3	; D3 AND(3)  18~
	GOTO	ANI	; D4 ANI     10~
	GOTO	AND1A	; D5 AND@(1) 18~
	GOTO	AND2A	; D6 AND@(2) 18~
	GOTO	AND3A	; D7 AND@(3) 18~
	GOTO	OR0	; D8 OR(0)   18~
	GOTO	OR1	; D9 OR(1)   18~
	GOTO	OR2	; DA OR(2)   18~
	GOTO	OR3	; DB OR(3)   18~
	GOTO	ORI	; DC ORI     10~
	GOTO	OR1A	; DD OR@(1)  18~
	GOTO	OR2A	; DE OR@(2)  18~
	GOTO	OR3A	; DF OR@(3)  18~
	GOTO	XOR0	; E0 XOR(0)  18~
	GOTO	XOR1	; E1 XOR(1)  18~
	GOTO	XOR2	; E2 XOR(2)  18~
	GOTO	XOR3	; E3 XOR(3)  18~
	GOTO	XRI	; E4 XRI     10~
	GOTO	XOR1A	; E5 XOR@(1) 18~
	GOTO	XOR2A	; E6 XOR@(2) 18~
	GOTO	XOR3A	; E7 XOR@(3) 18~
	GOTO	DAD0	; E8 DAD(0)  23~
	GOTO	DAD1	; E9 DAD(1)  23~
	GOTO	DAD2	; EA DAD(2)  23~
	GOTO	DAD3	; EB DAD(3)  23~
	GOTO	DAI	; EC DAI     15~
	GOTO	DAD1A	; ED DAD@(1) 23~
	GOTO	DAD2A	; EE DAD@(2) 23~
	GOTO	DAD3A	; EF DAD@(3) 23~
	GOTO	ADD0	; F0 ADD(0)  19~
	GOTO	ADD1	; F1 ADD(1)  19~
	GOTO	ADD2	; F2 ADD(2)  19~
	GOTO	ADD3	; F3 ADD(3)  19~
	GOTO	ADI	; F4 ADI     11~
	GOTO	ADD1A	; F5 ADD@(1) 19~
	GOTO	ADD2A	; F6 ADD@(2) 19~
	GOTO	ADD3A	; F7 ADD@(3) 19~
	GOTO	CAD0	; F8 CAD(0)  20~
	GOTO	CAD1	; F9 CAD(1)  20~
	GOTO	CAD2	; FA CAD(2)  20~
	GOTO	CAD3	; FB CAD(3)  20~
	GOTO	CAI	; FC CAI     12~	
	GOTO	CAD1A	; FD CAD@(1) 20~
	GOTO	CAD2A	; FE CAD@(2) 20~
	GOTO	CAD3A	; FF CAD@(3) 20~

; Critical opcode - ADE
ADE	ADD	EXT

; Execute SC/MP instruction (19)
; PCLATH must be HIGH(OPVEC)
EXEC	INCPC
	NOP
	NOP
	RDRAM	P0HI,P0LO
	MOVWF	PCL

; Opcode functions
CAE	MOVF	EXT,W
	MOVWF	DATUM
	COMF	DATUM
	ADD	DATUM
	GOTO	EXEC
RRL	RLF	STAT
	RRF	ACC
	RRF	STAT
	NOP
	GOTO	EXEC
LDE	MOVF	EXT,W
	MOVWF	ACC
	GOTO	PAD7
ORE	MOVF	EXT,W
	IORWF	ACC
	GOTO	PAD7
XRE	MOVF	EXT,W
	XORWF	ACC
	GOTO	PAD7
ANE	MOVF	EXT,W
	ANDWF	ACC
	GOTO	PAD7
SIO	BCF	STATUS,C
	RRF	EXT
	NOP
	NOP
	GOTO	EXEC
SR	BCF	STATUS,C
	RRF	ACC
	NOP
	NOP
	GOTO	EXEC
RR	RRF	ACC,W
	RRF	ACC
	GOTO	PAD2
SRL	RLF	STAT,W
	RRF	ACC
	GOTO	PAD2
CCL	BCF	STAT,CYL
	GOTO	PAD3
SCL	BSF	STAT,CYL
	GOTO	PAD3
DINT	BCF	STAT,IE
	GOTO	PAD8
IEN	BSF	STAT,IE
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	NOP
	GOTO	EXEC
CAS	MOVF	ACC,W
	ANDLW	B'11001111'
	MOVWF	STAT
	MOVWF	PORTA
	GOTO	PAD5
CSA	MOVF	PORTA,W
	ANDLW	B'00110000'
	IORWF	STAT,W
	MOVWF	ACC
	GOTO	EXEC
XAE	LJMP0	XAEX
XPAL0	LJMP0	XPAL0X
XPAL1	LJMP0	XPAL1X
XPAL2	LJMP0	XPAL2X
XPAL3	LJMP0	XPAL3X
XPAH0	LJMP0	XPAH0X
XPAH1	LJMP0	XPAH1X
XPAH2	LJMP0	XPAH2X
XPAH3	LJMP0	XPAH3X
XPPC1	XCHNG	P1HI,P0HI
	XCHNG	P1LO,P0LO
	GOTO	PAD2
XPPC2	XCHNG	P2HI,P0HI
	XCHNG	P2LO,P0LO
	GOTO	PAD2
XPPC3	XCHNG	P3HI,P0HI
	XCHNG	P3LO,P0LO
	GOTO	PAD2
JMP0	NOP
	NOP
	GOTO	JUMP0
JMP1	NOP
	NOP
	GOTO	JUMP1
JMP2	NOP
	NOP
	GOTO	JUMP2
JMP3	NOP
	NOP
	GOTO	JUMP3
JP0	NOP
	BTFSS	ACC,7
	GOTO	JUMP0
	GOTO	NOJMP
JP1	NOP
	BTFSS	ACC,7
	GOTO	JUMP1
	GOTO	NOJMP
JP2	NOP
	BTFSS	ACC,7
	GOTO	JUMP2
	GOTO	NOJMP
JP3	NOP
	BTFSS	ACC,7
	GOTO	JUMP3
	GOTO	NOJMP
JZ0	MOVF	ACC
	BTFSC	STATUS,Z
	GOTO	JUMP0
	GOTO	NOJMP
JZ1	MOVF	ACC
	BTFSC	STATUS,Z
	GOTO	JUMP1
	GOTO	NOJMP
JZ2	MOVF	ACC
	BTFSC	STATUS,Z
	GOTO	JUMP2
	GOTO	NOJMP
JZ3	MOVF	ACC
	BTFSC	STATUS,Z
	GOTO	JUMP3
	GOTO	NOJMP
JNZ0	MOVF	ACC
	BTFSS	STATUS,Z
	GOTO	JUMP0
	GOTO	NOJMP
JNZ1	MOVF	ACC
	BTFSS	STATUS,Z
	GOTO	JUMP1
	GOTO	NOJMP
JNZ2	MOVF	ACC
	BTFSS	STATUS,Z
	GOTO	JUMP2
	GOTO	NOJMP
JNZ3	MOVF	ACC
	BTFSS	STATUS,Z
	GOTO	JUMP3
	GOTO	NOJMP
ILD0	LJMP0	ILD0X
ILD1	LJMP0	ILD1X
ILD2	LJMP0	ILD2X
ILD3	LJMP0	ILD3X
DLD0	LJMP0	DLD0X
DLD1	LJMP0	DLD1X
DLD2	LJMP0	DLD2X
DLD3	LJMP0	DLD3X
LD0	LJMP0	LD0X
LD1	LJMP0	LD1X
LD2	LJMP0	LD2X
LD3	LJMP0	LD3X
LD1A	CALL	RDA1
	MOVWF	ACC
	GOTO	PAD5
LD2A	CALL	RDA2
	MOVWF	ACC
	GOTO	PAD5
LD3A	CALL	RDA3
	MOVWF	ACC
	GOTO	PAD5
AND0	LJMP0	AND0X
AND1	LJMP0	AND1X
AND2	LJMP0	AND2X
AND3	LJMP0	AND3X
AND1A	CALL	RDA1
	ANDWF	ACC
	GOTO	PAD5
AND2A	CALL	RDA2
	ANDWF	ACC
	GOTO	PAD5
AND3A	CALL	RDA3
	ANDWF	ACC
	GOTO	PAD5
OR0	LJMP0	OR0X
OR1	LJMP0	OR1X
OR2	LJMP0	OR2X
OR3	LJMP0	OR3X
OR1A	CALL	RDA1
	IORWF	ACC
	GOTO	PAD5
OR2A	CALL	RDA2
	IORWF	ACC
	GOTO	PAD5
OR3A	CALL	RDA3
	IORWF	ACC
	GOTO	PAD5
XOR0	LJMP0	XOR0X
XOR1	LJMP0	XOR1X
XOR2	LJMP0	XOR2X
XOR3	LJMP0	XOR3X
XOR1A	CALL	RDA1
	XORWF	ACC
	GOTO	PAD5
XOR2A	CALL	RDA2
	XORWF	ACC
	GOTO	PAD5
XOR3A	CALL	RDA3
	XORWF	ACC
	GOTO	PAD5
DAD0	LJMP0	DAD0X
DAD1	LJMP0	DAD1X
DAD2	LJMP0	DAD2X
DAD3	LJMP0	DAD3X
DAD1A	CALL	RDA1
	CALL	DADD
	GOTO	PAD13
DAD2A	CALL	RDA2
	CALL	DADD
	GOTO	PAD13
DAD3A	CALL	RDA3
	CALL	DADD
	GOTO	PAD13
ADD0	LJMP0	ADD0X
ADD1	LJMP0	ADD1X
ADD2	LJMP0	ADD2X
ADD3	LJMP0	ADD3X
ADI	GOP
	ADD	OPRND
	NOP
	GOTO	EXEC
ADD1A	ADMEMA	P1HI,P1LO
ADD2A	ADMEMA	P2HI,P2LO
ADD3A	ADMEMA	P3HI,P3LO
CAD1A	RDMEMA	P1HI,P1LO
	COMF	DATUM
	ADD	DATUM
	GOTO	PAD3
CAD2A	RDMEMA	P2HI,P2LO
	COMF	DATUM
	ADD	DATUM
	GOTO	PAD3
CAD3A	RDMEMA	P3HI,P3LO
	COMF	DATUM
	ADD	DATUM
	GOTO	PAD3
DAE	LJMP0	DAEX
DLY	LJMP0	DLYX
LDI	LJMP0	LDIX
ST0	LJMP0	ST0X
ST1	LJMP0	ST1X
ST2	LJMP0	ST2X
ST3	LJMP0	ST3X
ST1A	LJMP0	ST1AX
ST2A	LJMP0	ST2AX
ST3A	LJMP0	ST3AX
ANI	LJMP0	ANIX
ORI	LJMP0	ORIX
XRI	LJMP0	XRIX
DAI	LJMP0	DAIX
CAD0	LJMP0	CAD0X
CAD1	LJMP0	CAD1X
CAD2	LJMP0	CAD2X
CAD3	LJMP0	CAD3X
CAI	LJMP0	CAIX

; Opcode support
JUMP0	GEAPC	P0HI,P0LO
JUMP1	GEAPC	P1HI,P1LO
JUMP2	GEAPC	P2HI,P2LO
JUMP3	GEAPC	P3HI,P3LO
NOJMP	INCPC
	GOTO	PAD16
RDA1	RDMEMA	P1HI,P1LO
	RETURN
RDA2	RDMEMA	P2HI,P2LO
	RETURN
RDA3	RDMEMA	P3HI,P3LO
DEL4	RETURN
DADD	DAD	DATUM
	RETURN
XHALT
PAD21	CALL	DEL4
PAD17	NOP
XPPC0
PAD16	NOP
PAD15	NOP
PAD14	NOP
PAD13	NOP
PAD12	NOP
PAD11	NOP
PAD10	NOP
PAD9	NOP
PAD8	NOP
PAD7	NOP
XNOP
PAD6	NOP
PAD5	NOP
PAD4	NOP
PAD3	NOP
PAD2	GOTO	EXEC
ILL	LJMP0	RESET

; Pages 2,3 - NIBL ROM table
	ORG	H'1000'
NIBL	DW	H'08', H'C4', H'10', H'36', H'C4', H'1C', H'32', H'C4', H'11', H'35', H'C4', H'20', H'31', H'C4', H'FF', H'C9'
	DW	H'00', H'C9', H'01', H'C4', H'0D', H'C9', H'FF', H'C4', H'02', H'CA', H'F6', H'31', H'C4', H'20', H'35', H'B9'
	DW	H'02', H'01', H'C1', H'80', H'E4', H'0D', H'98', H'02', H'BA', H'F6', H'C4', H'20', H'35', H'C4', H'FF', H'C9'
	DW	H'00', H'C9', H'01', H'C4', H'0D', H'C9', H'FF', H'35', H'02', H'F4', H'10', H'E4', H'80', H'98', H'04', H'E4'
	DW	H'80', H'90', H'E9', H'C4', H'00', H'CA', H'F4', H'CA', H'F5', H'C4', H'58', H'CA', H'FB', H'C4', H'0C', H'CA'
	DW	H'FA', H'C4', H'00', H'CA', H'EA', H'01', H'C4', H'00', H'CA', H'80', H'AA', H'EA', H'01', H'C4', H'34', H'60'
	DW	H'9C', H'F4', H'C4', H'50', H'CA', H'FD', H'C4', H'7A', H'CA', H'FF', H'C4', H'6A', H'CA', H'FC', H'C4', H'A6'
	DW	H'CA', H'F9', H'C4', H'8A', H'CA', H'FE', H'C2', H'FB', H'33', H'C2', H'FA', H'37', H'C7', H'01', H'01', H'C7'
	DW	H'01', H'33', H'CA', H'FB', H'40', H'D4', H'0F', H'DC', H'00', H'37', H'CA', H'FA', H'40', H'D4', H'F0', H'E4'
	DW	H'20', H'98', H'2F', H'E4', H'A0', H'98', H'07', H'E4', H'C0', H'98', H'E1', H'3F', H'90', H'D8', H'C2', H'F9'
	DW	H'E4', H'D6', H'9C', H'04', H'C4', H'0A', H'90', H'60', H'E4', H'D6', H'33', H'CA', H'EA', H'C4', H'10', H'37'
	DW	H'01', H'C2', H'FB', H'CF', H'01', H'C2', H'FA', H'CF', H'01', H'C2', H'EA', H'33', H'CA', H'F9', H'40', H'37'
	DW	H'90', H'BA', H'CA', H'E7', H'C5', H'01', H'E4', H'20', H'98', H'FA', H'C5', H'FF', H'C2', H'FA', H'37', H'CA'
	DW	H'EC', H'C2', H'FB', H'33', H'CA', H'ED', H'C7', H'01', H'01', H'BA', H'E7', H'40', H'D4', H'7F', H'E5', H'01'
	DW	H'9C', H'07', H'40', H'94', H'F1', H'90', H'95', H'90', H'8D', H'C2', H'E7', H'01', H'C5', H'80', H'C2', H'ED'
	DW	H'33', H'C2', H'EC', H'37', H'90', H'CA', H'C4', H'10', H'37', H'C2', H'F9', H'33', H'C7', H'FF', H'01', H'C7'
	DW	H'FF', H'33', H'CA', H'F9', H'40', H'37', H'90', H'B8', H'90', H'41', H'C2', H'FC', H'E4', H'7A', H'98', H'1C'
	DW	H'AA', H'FC', H'AA', H'FC', H'33', H'C4', H'10', H'37', H'C2', H'F4', H'98', H'0A', H'35', H'CB', H'FF', H'35'
	DW	H'31', H'CB', H'FE', H'31', H'90', H'C1', H'C4', H'FF', H'CB', H'FF', H'90', H'BB', H'C4', H'0A', H'90', H'1B'
	DW	H'C5', H'01', H'E4', H'20', H'98', H'FA', H'E4', H'2D', H'98', H'04', H'E4', H'37', H'9C', H'01', H'3F', H'C4'
	DW	H'04', H'90', H'08', H'C2', H'FC', H'E4', H'6A', H'9C', H'04', H'C4', H'09', H'90', H'40', H'BA', H'FC', H'BA'
	DW	H'FC', H'33', H'C4', H'10', H'37', H'C3', H'01', H'94', H'06', H'C4', H'00', H'CA', H'F4', H'90', H'88', H'35'
	DW	H'C3', H'00', H'31', H'C4', H'01', H'CA', H'F4', H'90', H'F4', H'C2', H'F2', H'94', H'04', H'C4', H'08', H'90'
	DW	H'1C', H'C4', H'01', H'CA', H'F4', H'3F', H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'C5', H'01', H'E4', H'22'
	DW	H'98', H'DB', H'E4', H'2F', H'98', H'05', H'E4', H'0D', H'3F', H'90', H'EB', H'C4', H'07', H'90', H'35', H'C4'
	DW	H'10', H'37', H'AA', H'FD', H'AA', H'FD', H'33', H'C4', H'0A', H'CB', H'FE', H'C4', H'00', H'CB', H'FF', H'C4'
	DW	H'05', H'CA', H'E7', H'C4', H'FF', H'CB', H'05', H'C3', H'FD', H'94', H'13', H'C4', H'2D', H'CB', H'04', H'C4'
	DW	H'00', H'03', H'FB', H'FC', H'CB', H'FC', H'C4', H'00', H'FB', H'FD', H'CB', H'FD', H'90', H'9F', H'C4', H'20'
	DW	H'CB', H'04', H'90', H'99', H'90', H'57', H'AA', H'FD', H'AA', H'FD', H'31', H'C4', H'10', H'35', H'AA', H'E7'
	DW	H'01', H'C1', H'01', H'DC', H'30', H'C9', H'80', H'C1', H'FD', H'D9', H'FC', H'98', H'0A', H'C4', H'0F', H'CA'
	DW	H'FA', H'C4', H'33', H'CA', H'FB', H'90', H'DB', H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'C2', H'F5', H'9C'
	DW	H'06', H'C1', H'04', H'3F', H'C2', H'E7', H'01', H'C5', H'80', H'C1', H'00', H'3F', H'C5', H'FF', H'94', H'FB'
	DW	H'C4', H'50', H'CA', H'FD', H'C2', H'F5', H'9C', H'BA', H'C4', H'20', H'3F', H'90', H'B5', H'C4', H'0F', H'37'
	DW	H'C4', H'C1', H'33', H'C4', H'0D', H'3F', H'C4', H'0A', H'3F', H'90', H'A7', H'C4', H'05', H'CA', H'EB', H'C2'
	DW	H'EB', H'CA', H'EA', H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'C4', H'0D', H'3F', H'C4', H'0A', H'3F', H'C4'
	DW	H'0F', H'35', H'C4', H'3B', H'31', H'BA', H'EB', H'98', H'06', H'C5', H'01', H'94', H'FC', H'90', H'F6', H'C5'
	DW	H'01', H'3F', H'C1', H'FF', H'94', H'F9', H'C2', H'EA', H'E4', H'0E', H'98', H'0D', H'C4', H'0F', H'35', H'C4'
	DW	H'3B', H'31', H'C5', H'01', H'3F', H'C1', H'FF', H'94', H'F9', H'C2', H'F4', H'98', H'4D', H'C4', H'20', H'3F'
	DW	H'C4', H'41', H'3F', H'C4', H'54', H'3F', H'C4', H'10', H'37', H'AA', H'FD', H'AA', H'FD', H'33', H'C2', H'F7'
	DW	H'CB', H'FF', H'C2', H'F8', H'CB', H'FE', H'C4', H'31', H'CA', H'FB', H'C4', H'0E', H'CA', H'FA', H'90', H'99'
	DW	H'C4', H'0E', H'90', H'99', H'C2', H'F4', H'98', H'22', H'C1', H'00', H'D4', H'80', H'9C', H'1C', H'06', H'D4'
	DW	H'20', H'98', H'ED', H'C1', H'FF', H'E4', H'0D', H'9C', H'08', H'C5', H'01', H'CA', H'F7', H'C5', H'02', H'CA'
	DW	H'F8', H'C4', H'0C', H'CA', H'FA', H'C4', H'86', H'CA', H'FB', H'3F', H'C4', H'00', H'CA', H'F4', H'C4', H'50'
	DW	H'CA', H'FD', H'C4', H'1C', H'CA', H'FB', H'C4', H'0C', H'CA', H'FA', H'C4', H'A6', H'CA', H'F9', H'90', H'BE'
	DW	H'AA', H'F4', H'C2', H'E9', H'35', H'C2', H'E8', H'31', H'C4', H'6A', H'CA', H'FC', H'C4', H'8A', H'CA', H'FE'
	DW	H'C4', H'7A', H'CA', H'FF', H'3F', H'90', H'A7', H'90', H'A9', H'C1', H'00', H'E4', H'80', H'94', H'18', H'C4'
	DW	H'10', H'37', H'AA', H'FD', H'AA', H'FD', H'33', H'C5', H'01', H'CB', H'FF', H'C5', H'01', H'CB', H'FE', H'C5'
	DW	H'01', H'C4', H'01', H'CA', H'F5', H'90', H'DE', H'C4', H'00', H'CA', H'F5', H'C4', H'02', H'37', H'C4', H'83'
	DW	H'33', H'3F', H'90', H'D1', H'90', H'D1', H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'06', H'D4', H'20', H'98'
	DW	H'E6', H'C5', H'01', H'E4', H'0D', H'98', H'05', H'E4', H'0D', H'3F', H'90', H'F0', H'C4', H'0D', H'3F', H'C4'
	DW	H'0A', H'3F', H'02', H'C4', H'4B', H'CA', H'FB', H'C4', H'0C', H'CA', H'FA', H'90', H'AC', H'C4', H'10', H'37'
	DW	H'BA', H'FD', H'BA', H'FD', H'33', H'02', H'C3', H'FE', H'F3', H'00', H'CB', H'FE', H'C3', H'FF', H'F3', H'01'
	DW	H'CB', H'FF', H'90', H'BE', H'C4', H'10', H'37', H'BA', H'FD', H'BA', H'FD', H'33', H'03', H'C3', H'FE', H'FB'
	DW	H'00', H'CB', H'FE', H'C3', H'FF', H'FB', H'01', H'CB', H'FF', H'90', H'A7', H'C4', H'10', H'37', H'C2', H'FD'
	DW	H'33', H'03', H'C4', H'00', H'FB', H'FE', H'CB', H'FE', H'C4', H'00', H'FB', H'FF', H'CB', H'FF', H'90', H'D2'
	DW	H'90', H'92', H'C4', H'10', H'37', H'C2', H'FD', H'33', H'C3', H'FF', H'E3', H'FD', H'CA', H'EA', H'C3', H'FF'
	DW	H'94', H'0D', H'03', H'C4', H'00', H'FB', H'FE', H'CB', H'FE', H'C4', H'00', H'FB', H'FF', H'CB', H'FF', H'C3'
	DW	H'FD', H'94', H'0D', H'03', H'C4', H'00', H'FB', H'FC', H'CB', H'FC', H'C4', H'00', H'FB', H'FD', H'CB', H'FD'
	DW	H'C4', H'00', H'CB', H'00', H'CB', H'01', H'CB', H'02', H'CB', H'03', H'C4', H'10', H'CA', H'EB', H'C3', H'FF'
	DW	H'1F', H'CB', H'FF', H'C3', H'FE', H'1F', H'CB', H'FE', H'06', H'94', H'11', H'02', H'C3', H'02', H'F3', H'FC'
	DW	H'CB', H'02', H'C3', H'03', H'F3', H'FD', H'CB', H'03', H'90', H'02', H'90', H'A4', H'02', H'C3', H'03', H'1F'
	DW	H'CB', H'03', H'C3', H'02', H'1F', H'CB', H'02', H'C3', H'01', H'1F', H'CB', H'01', H'C3', H'00', H'1F', H'CB'
	DW	H'00', H'BA', H'EB', H'9C', H'C9', H'90', H'02', H'90', H'85', H'C2', H'EA', H'94', H'0D', H'03', H'C4', H'00'
	DW	H'FB', H'00', H'CB', H'00', H'C4', H'00', H'FB', H'01', H'CB', H'01', H'C3', H'00', H'CB', H'FC', H'C3', H'01'
	DW	H'CB', H'FD', H'BA', H'FD', H'BA', H'FD', H'90', H'DF', H'C4', H'10', H'37', H'C2', H'FD', H'33', H'C3', H'FF'
	DW	H'DB', H'FE', H'9C', H'04', H'C4', H'0D', H'90', H'B2', H'C3', H'FD', H'E3', H'FF', H'CA', H'EA', H'C3', H'FD'
	DW	H'94', H'11', H'C4', H'00', H'03', H'FB', H'FC', H'CB', H'03', H'C4', H'00', H'FB', H'FD', H'CB', H'02', H'90'
	DW	H'0A', H'90', H'B4', H'C3', H'FD', H'CB', H'02', H'C3', H'FC', H'CB', H'03', H'C3', H'FF', H'94', H'0D', H'C4'
	DW	H'00', H'03', H'FB', H'FE', H'CB', H'FE', H'C4', H'00', H'FB', H'FF', H'CB', H'FF', H'C4', H'00', H'CB', H'01'
	DW	H'CB', H'00', H'CA', H'EB', H'CB', H'FD', H'CB', H'FC', H'02', H'C3', H'FC', H'F3', H'FC', H'CB', H'FC', H'C3'
	DW	H'FD', H'F3', H'FD', H'CB', H'FD', H'02', H'C3', H'03', H'F3', H'03', H'CB', H'03', H'C3', H'02', H'F3', H'02'
	DW	H'CB', H'02', H'C3', H'01', H'F3', H'01', H'CB', H'01', H'C3', H'00', H'F3', H'00', H'CB', H'00', H'03', H'C3'
	DW	H'01', H'FB', H'FE', H'CB', H'01', H'C3', H'00', H'FB', H'FF', H'CB', H'00', H'94', H'11', H'02', H'C3', H'01'
	DW	H'F3', H'FE', H'CB', H'01', H'C3', H'00', H'F3', H'FF', H'CB', H'00', H'90', H'08', H'90', H'93', H'C3', H'FC'
	DW	H'DC', H'01', H'CB', H'FC', H'AA', H'EB', H'E4', H'10', H'9C', H'AE', H'C2', H'EA', H'94', H'0D', H'C4', H'00'
	DW	H'03', H'FB', H'FC', H'CB', H'FC', H'C4', H'00', H'FB', H'FD', H'CB', H'FD', H'BA', H'FD', H'BA', H'FD', H'90'
	DW	H'DB', H'C4', H'10', H'37', H'C2', H'FD', H'33', H'C7', H'FD', H'01', H'C3', H'01', H'CA', H'80', H'02', H'40'
	DW	H'F4', H'01', H'01', H'C3', H'02', H'CA', H'80', H'33', H'CA', H'FD', H'C4', H'00', H'37', H'C4', H'75', H'33'
	DW	H'3F', H'C5', H'01', H'E4', H'20', H'98', H'FA', H'C1', H'FF', H'03', H'FC', H'5B', H'94', H'05', H'03', H'FC'
	DW	H'E6', H'94', H'12', H'C5', H'FF', H'C2', H'FB', H'33', H'C2', H'FA', H'37', H'C3', H'00', H'CA', H'FA', H'C3'
	DW	H'01', H'CA', H'FB', H'90', H'D5', H'01', H'C1', H'00', H'03', H'FC', H'5B', H'94', H'05', H'03', H'FC', H'E6'
	DW	H'94', H'E1', H'C4', H'10', H'37', H'AA', H'FD', H'33', H'02', H'40', H'70', H'CB', H'FF', H'C4', H'02', H'02'
	DW	H'F2', H'FB', H'CA', H'FB', H'C4', H'00', H'F2', H'FA', H'CA', H'FA', H'90', H'AE', H'C4', H'10', H'37', H'AA'
	DW	H'FD', H'33', H'C3', H'FE', H'01', H'C2', H'80', H'CB', H'FE', H'02', H'40', H'F4', H'01', H'01', H'C2', H'80'
	DW	H'CB', H'FF', H'90', H'96', H'C4', H'01', H'90', H'12', H'C4', H'02', H'90', H'0E', H'C4', H'03', H'90', H'0A'
	DW	H'C4', H'04', H'90', H'06', H'C4', H'05', H'90', H'02', H'C4', H'06', H'CA', H'EB', H'C4', H'10', H'37', H'BA'
	DW	H'FD', H'BA', H'FD', H'33', H'03', H'C3', H'FE', H'FB', H'00', H'CA', H'EF', H'C3', H'FF', H'FB', H'01', H'CA'
	DW	H'EE', H'E3', H'FF', H'01', H'C3', H'FF', H'E3', H'01', H'50', H'E2', H'EE', H'CA', H'EA', H'C2', H'EE', H'DA'
	DW	H'EF', H'98', H'02', H'C4', H'80', H'E4', H'80', H'01', H'BA', H'EB', H'9C', H'05', H'40', H'90', H'2B', H'90'
	DW	H'B1', H'BA', H'EB', H'9C', H'05', H'40', H'E4', H'80', H'90', H'20', H'BA', H'EB', H'9C', H'04', H'C2', H'EA'
	DW	H'90', H'18', H'BA', H'EB', H'9C', H'05', H'40', H'DA', H'EA', H'90', H'0F', H'BA', H'EB', H'9C', H'07', H'40'
	DW	H'DA', H'EA', H'E4', H'80', H'90', H'04', H'C2', H'EA', H'E4', H'80', H'94', H'04', H'C4', H'01', H'90', H'02'
	DW	H'C4', H'00', H'CB', H'FE', H'C4', H'00', H'CB', H'FF', H'C4', H'00', H'37', H'C4', H'F5', H'33', H'3F', H'90'
	DW	H'BE', H'C2', H'EF', H'DA', H'EE', H'98', H'02', H'90', H'B6', H'C5', H'01', H'E4', H'0D', H'9C', H'FA', H'C4'
	DW	H'02', H'37', H'C4', H'83', H'33', H'3F', H'90', H'A7', H'C4', H'01', H'90', H'06', H'C4', H'02', H'90', H'02'
	DW	H'C4', H'03', H'CA', H'EB', H'C4', H'10', H'37', H'BA', H'FD', H'BA', H'FD', H'33', H'BA', H'EB', H'9C', H'0E'
	DW	H'C3', H'01', H'D3', H'FF', H'CB', H'FF', H'C3', H'00', H'D3', H'FE', H'CB', H'FE', H'90', H'D8', H'BA', H'EB'
	DW	H'9C', H'0E', H'C3', H'01', H'DB', H'FF', H'CB', H'FF', H'C3', H'00', H'DB', H'FE', H'CB', H'FE', H'90', H'C6'
	DW	H'C7', H'01', H'E4', H'FF', H'CB', H'FF', H'C7', H'01', H'E4', H'FF', H'CB', H'FF', H'33', H'CA', H'FD', H'90'
	DW	H'B5', H'C2', H'F1', H'31', H'CA', H'F1', H'C2', H'F0', H'35', H'CA', H'F0', H'3F', H'C2', H'F4', H'98', H'01'
	DW	H'3F', H'C4', H'03', H'CA', H'EB', H'C4', H'02', H'37', H'C4', H'1E', H'33', H'3F', H'AA', H'FD', H'AA', H'FD'
	DW	H'33', H'C4', H'10', H'37', H'C4', H'00', H'CB', H'FF', H'CB', H'FE', H'CA', H'EB', H'C5', H'01', H'E4', H'20'
	DW	H'98', H'FA', H'C5', H'FF', H'C1', H'00', H'03', H'FC', H'3A', H'94', H'09', H'03', H'FC', H'F6', H'94', H'13'
	DW	H'90', H'32', H'90', H'BB', H'03', H'FC', H'0D', H'94', H'2B', H'03', H'FC', H'FA', H'94', H'02', H'90', H'24'
	DW	H'02', H'F4', H'0A', H'01', H'C4', H'04', H'CA', H'EA', H'CA', H'EB', H'C3', H'FE', H'02', H'F3', H'FE', H'CB'
	DW	H'FE', H'C3', H'FF', H'F3', H'FF', H'CB', H'FF', H'BA', H'EA', H'9C', H'EF', H'C3', H'FE', H'58', H'CB', H'FE'
	DW	H'C5', H'01', H'90', H'C0', H'C2', H'EB', H'9C', H'87', H'C4', H'05', H'90', H'97', H'C5', H'01', H'E4', H'20'
	DW	H'98', H'FA', H'C5', H'FF', H'03', H'FC', H'3A', H'94', H'05', H'03', H'FC', H'F6', H'94', H'21', H'C2', H'FB'
	DW	H'33', H'C2', H'FA', H'37', H'C3', H'00', H'CA', H'FA', H'C3', H'01', H'CA', H'FB', H'90', H'A4', H'C4', H'02'
	DW	H'02', H'F2', H'FB', H'CA', H'FB', H'C4', H'00', H'F2', H'FA', H'CA', H'FA', H'90', H'95', H'90', H'CB', H'01'
	DW	H'C4', H'10', H'37', H'AA', H'FD', H'AA', H'FD', H'33', H'C4', H'00', H'CB', H'FF', H'40', H'CB', H'FE', H'C5'
	DW	H'01', H'C1', H'00', H'03', H'FC', H'3A', H'94', H'D6', H'03', H'FC', H'F6', H'94', H'02', H'90', H'CF', H'01'
	DW	H'C3', H'FF', H'CB', H'01', H'C3', H'FE', H'CB', H'00', H'C4', H'02', H'CA', H'EA', H'02', H'C3', H'FE', H'F3'
	DW	H'FE', H'CB', H'FE', H'C3', H'FF', H'F3', H'FF', H'CB', H'FF', H'D4', H'80', H'9C', H'34', H'BA', H'EA', H'9C'
	DW	H'EB', H'02', H'C3', H'FE', H'F3', H'00', H'CB', H'FE', H'C3', H'FF', H'F3', H'01', H'CB', H'FF', H'D4', H'80'
	DW	H'9C', H'1F', H'02', H'C3', H'FE', H'F3', H'FE', H'CB', H'FE', H'C3', H'FF', H'F3', H'FF', H'CB', H'FF', H'D4'
	DW	H'80', H'9C', H'0E', H'02', H'40', H'F3', H'FE', H'CB', H'FE', H'C4', H'00', H'F3', H'FF', H'CB', H'FF', H'94'
	DW	H'9E', H'C4', H'06', H'90', H'88', H'90', H'84', H'C4', H'10', H'35', H'C4', H'D6', H'31', H'C4', H'00', H'CA'
	DW	H'E7', H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'C2', H'F4', H'98', H'08', H'C4', H'3F', H'3F', H'C4', H'20'
	DW	H'3F', H'90', H'03', H'C4', H'3E', H'3F', H'C4', H'0F', H'37', H'C4', H'76', H'33', H'3F', H'C4', H'C1', H'33'
	DW	H'40', H'98', H'F3', H'E4', H'0A', H'98', H'EF', H'40', H'E4', H'0D', H'98', H'50', H'40', H'E4', H'5F', H'98'
	DW	H'41', H'40', H'E4', H'08', H'98', H'36', H'40', H'E4', H'15', H'98', H'0F', H'40', H'E4', H'03', H'9C', H'1A'
	DW	H'C4', H'5E', H'3F', H'C4', H'43', H'3F', H'C4', H'0E', H'90', H'A9', H'C4', H'5E', H'3F', H'C4', H'55', H'3F'
	DW	H'C4', H'0D', H'3F', H'C4', H'0A', H'3F', H'90', H'9F', H'90', H'9B', H'40', H'CD', H'01', H'AA', H'E7', H'E4'
	DW	H'48', H'9C', H'B3', H'C4', H'0D', H'01', H'40', H'3F', H'90', H'12', H'90', H'87', H'C4', H'20', H'3F', H'C4'
	DW	H'08', H'3F', H'C2', H'E7', H'98', H'A0', H'BA', H'E7', H'C5', H'FF', H'90', H'9A', H'40', H'CD', H'01', H'C4'
	DW	H'0A', H'3F', H'C4', H'10', H'35', H'C4', H'D6', H'31', H'90', H'CE', H'C4', H'10', H'37', H'C2', H'FD', H'33'
	DW	H'C3', H'FF', H'35', H'01', H'C3', H'FE', H'31', H'CA', H'EF', H'C1', H'00', H'CB', H'FE', H'C4', H'00', H'CB'
	DW	H'FF', H'C2', H'EF', H'31', H'40', H'35', H'90', H'B0', H'C4', H'10', H'37', H'C2', H'FD', H'33', H'C7', H'FE'
	DW	H'01', H'C7', H'FF', H'CA', H'EA', H'C7', H'FF', H'33', H'CA', H'FD', H'C2', H'EA', H'37', H'40', H'CB', H'00'
	DW	H'90', H'C6', H'90', H'A6', H'C4', H'10', H'37', H'C2', H'FD', H'33', H'C3', H'01', H'CA', H'F7', H'C3', H'00'
	DW	H'CA', H'F8', H'C2', H'F1', H'33', H'C2', H'F0', H'37', H'C4', H'04', H'CA', H'E7', H'C7', H'01', H'E4', H'0D'
	DW	H'98', H'04', H'AA', H'E7', H'90', H'F6', H'C2', H'E7', H'E4', H'04', H'9C', H'02', H'CA', H'E7', H'C2', H'E7'
	DW	H'01', H'C2', H'F2', H'94', H'06', H'D4', H'7F', H'CA', H'F2', H'90', H'18', H'C5', H'03', H'40', H'02', H'F4'
	DW	H'FC', H'01', H'C5', H'01', H'E4', H'0D', H'98', H'0B', H'40', H'02', H'F4', H'FF', H'01', H'90', H'F3', H'90'
	DW	H'AF', H'90', H'AF', H'40', H'DA', H'E7', H'98', H'F7', H'C4', H'7A', H'CA', H'FF', H'C4', H'6A', H'CA', H'FC'
	DW	H'C4', H'8A', H'CA', H'FE', H'40', H'98', H'60', H'94', H'10', H'C1', H'00', H'C9', H'80', H'C5', H'01', H'94'
	DW	H'F8', H'C1', H'00', H'94', H'F4', H'C9', H'80', H'90', H'4E', H'C1', H'FE', H'CA', H'EA', H'C4', H'FF', H'C9'
	DW	H'FE', H'C4', H'50', H'C9', H'FF', H'C5', H'01', H'94', H'FC', H'C1', H'00', H'94', H'F8', H'35', H'CA', H'EE'
	DW	H'35', H'31', H'CA', H'EF', H'31', H'C2', H'EF', H'02', H'70', H'C4', H'00', H'F2', H'EE', H'E2', H'EE', H'D4'
	DW	H'F0', H'98', H'03', H'C4', H'00', H'01', H'C4', H'FF', H'C9', H'80', H'C5', H'FF', H'94', H'FA', H'C1', H'01'
	DW	H'E4', H'50', H'98', H'04', H'C1', H'00', H'90', H'F0', H'C2', H'EA', H'C9', H'00', H'C4', H'0D', H'C9', H'01'
	DW	H'40', H'9C', H'04', H'C4', H'02', H'90', H'8A', H'C2', H'E7', H'98', H'84', H'C2', H'F1', H'31', H'C2', H'F0'
	DW	H'35', H'C2', H'F3', H'33', H'C2', H'F2', H'37', H'C2', H'F7', H'CF', H'01', H'C2', H'F8', H'CF', H'01', H'C2'
	DW	H'E7', H'CF', H'01', H'C5', H'01', H'CF', H'01', H'E4', H'0D', H'9C', H'F8', H'90', H'DC', H'C4', H'00', H'37'
	DW	H'C4', H'75', H'33', H'3F', H'90', H'CF', H'BA', H'FD', H'BA', H'FD', H'33', H'C4', H'10', H'37', H'C3', H'00'
	DW	H'CA', H'EF', H'C3', H'01', H'CA', H'EE', H'90', H'E5', H'C2', H'FF', H'01', H'40', H'E4', H'7A', H'9C', H'04'
	DW	H'C4', H'0F', H'90', H'E0', H'C2', H'EF', H'DA', H'EE', H'98', H'06', H'BA', H'FF', H'BA', H'FF', H'90', H'CD'
	DW	H'40', H'33', H'C4', H'10', H'37', H'C3', H'FF', H'35', H'C3', H'FE', H'31', H'90', H'C0', H'C2', H'EF', H'D4'
	DW	H'F7', H'07', H'90', H'B9', H'90', H'BE', H'C4', H'10', H'37', H'AA', H'FD', H'AA', H'FD', H'33', H'06', H'CB'
	DW	H'FE', H'C4', H'00', H'CB', H'FF', H'90', H'EB', H'C2', H'EE', H'37', H'C2', H'EF', H'33', H'C7', H'FF', H'3F'
	DW	H'C4', H'10', H'36', H'C4', H'1C', H'32', H'90', H'DA', H'C2', H'FF', H'E4', H'8A', H'9C', H'04', H'C4', H'0A'
	DW	H'90', H'D2', H'AA', H'FF', H'AA', H'FF', H'33', H'C4', H'10', H'37', H'35', H'CB', H'FF', H'35', H'31', H'CB'
	DW	H'FE', H'31', H'90', H'BE', H'C2', H'E9', H'37', H'C2', H'E8', H'33', H'C3', H'00', H'94', H'02', H'90', H'07'
	DW	H'C3', H'02', H'01', H'C7', H'80', H'90', H'F3', H'C7', H'02', H'AA', H'FD', H'AA', H'FD', H'33', H'01', H'C4'
	DW	H'10', H'37', H'CB', H'FF', H'40', H'CB', H'FE', H'90', H'D9', H'C5', H'01', H'E4', H'0D', H'9C', H'FA', H'3F'
	DW	H'C2', H'FD', H'33', H'C4', H'10', H'37', H'C3', H'03', H'CB', H'FE', H'C3', H'02', H'CB', H'FF', H'90', H'C2'
	DW	H'90', H'AE', H'C4', H'08', H'CA', H'EB', H'C2', H'E5', H'01', H'C2', H'E4', H'CA', H'E9', H'C2', H'E5', H'02'
	DW	H'70', H'01', H'C2', H'E4', H'02', H'F2', H'E9', H'CA', H'E4', H'BA', H'EB', H'9C', H'F0', H'40', H'02', H'F4'
	DW	H'07', H'01', H'C2', H'E4', H'02', H'F4', H'07', H'1E', H'CA', H'E4', H'AA', H'E6', H'98', H'03', H'40', H'CA'
	DW	H'E5', H'C2', H'FD', H'33', H'C4', H'10', H'37', H'C4', H'01', H'CB', H'00', H'C4', H'00', H'CB', H'01', H'C3'
	DW	H'FE', H'CB', H'02', H'C3', H'FF', H'CB', H'03', H'C3', H'FC', H'CB', H'04', H'C3', H'FD', H'CB', H'05', H'C2'
	DW	H'E4', H'CB', H'FE', H'C2', H'E5', H'E4', H'FF', H'D4', H'7F', H'CB', H'FF', H'C7', H'06', H'33', H'CA', H'FD'
	DW	H'90', H'9C', H'90', H'9C', H'AA', H'FD', H'AA', H'FD', H'33', H'C4', H'10', H'37', H'C4', H'00', H'CB', H'FF'
	DW	H'C4', H'01', H'CB', H'FE', H'90', H'EA', H'C2', H'FE', H'E4', H'A6', H'9C', H'04', H'C4', H'0A', H'90', H'E2'
	DW	H'E4', H'A6', H'31', H'CA', H'F1', H'C4', H'10', H'35', H'CA', H'F0', H'C2', H'FD', H'33', H'C4', H'10', H'37'
	DW	H'C3', H'F9', H'CD', H'01', H'C3', H'FC', H'CD', H'01', H'C3', H'FD', H'CD', H'01', H'C3', H'FE', H'CD', H'01'
	DW	H'C3', H'FF', H'CD', H'01', H'C2', H'F1', H'CD', H'01', H'C2', H'F0', H'CD', H'01', H'35', H'C2', H'F1', H'31'
	DW	H'CA', H'FE', H'C7', H'FC', H'33', H'CA', H'FD', H'90', H'A7', H'C2', H'FE', H'E4', H'8A', H'9C', H'04', H'C4'
	DW	H'0B', H'90', H'BB', H'E4', H'8A', H'31', H'CA', H'F1', H'C4', H'10', H'35', H'CA', H'F0', H'C2', H'FD', H'33'
	DW	H'C4', H'10', H'37', H'C7', H'FF', H'E1', H'F9', H'98', H'04', H'C4', H'0C', H'90', H'A1', H'E1', H'F9', H'01'
	DW	H'C2', H'80', H'02', H'F1', H'FC', H'CA', H'80', H'CB', H'00', H'C6', H'01', H'C2', H'80', H'F1', H'FD', H'CA'
	DW	H'80', H'CB', H'01', H'C6', H'FF', H'C1', H'FA', H'CB', H'02', H'C1', H'FB', H'CB', H'03', H'C1', H'FD', H'94'
	DW	H'10', H'C4', H'04', H'CA', H'EB', H'C7', H'01', H'E4', H'FF', H'CB', H'FF', H'BA', H'EB', H'9C', H'F6', H'90'
	DW	H'02', H'C7', H'04', H'33', H'CA', H'FD', H'C2', H'F1', H'31', H'C2', H'F0', H'35', H'90', H'99', H'C2', H'EF'
	DW	H'98', H'08', H'C2', H'FE', H'02', H'F4', H'F9', H'CA', H'FE', H'3F', H'C2', H'FE', H'33', H'C4', H'10', H'37'
	DW	H'C3', H'FF', H'35', H'C3', H'FE', H'31', H'90', H'E4', H'90', H'A1', H'C2', H'EE', H'35', H'C2', H'EF', H'31'
	DW	H'C4', H'0F', H'37', H'C4', H'C1', H'33', H'C5', H'01', H'E4', H'0D', H'98', H'D0', H'E4', H'0D', H'3F', H'06'
	DW	H'D4', H'20', H'9C', H'F2', H'90', H'C6', H'C2', H'EE', H'37', H'C2', H'EF', H'33', H'C5', H'01', H'CF', H'01'
	DW	H'E4', H'0D', H'9C', H'F8', H'90', H'B6', H'C2', H'EF', H'33', H'C2', H'EE', H'37', H'C5', H'01', H'E4', H'22'
	DW	H'98', H'0E', H'E4', H'2F', H'9C', H'04', H'C4', H'07', H'90', H'BE', H'E4', H'0D', H'CF', H'01', H'90', H'EC'
	DW	H'C4', H'0D', H'CB', H'00', H'90', H'DE', H'C2', H'FD', H'33', H'C4', H'10', H'37', H'C7', H'FF', H'35', H'C7'
	DW	H'FF', H'31', H'C7', H'FF', H'01', H'C7', H'FF', H'33', H'CA', H'FD', H'40', H'37', H'C5', H'01', H'CF', H'01'
	DW	H'E4', H'0D', H'98', H'C0', H'06', H'D4', H'20', H'9C', H'F3', H'90', H'B9', H'AA', H'FD', H'AA', H'FD', H'33'
	DW	H'C4', H'10', H'37', H'C2', H'F6', H'CB', H'FE', H'C4', H'00', H'CB', H'FF', H'90', H'A7', H'C2', H'EF', H'D4'
	DW	H'07', H'9C', H'02', H'C4', H'01', H'CA', H'F6', H'3F', H'C2', H'F6', H'E4', H'01', H'9C', H'09', H'C4', H'11'
	DW	H'CA', H'E9', H'C4', H'20', H'CA', H'E8', H'3F', H'E4', H'01', H'01', H'C4', H'04', H'CA', H'EB', H'40', H'02'
	DW	H'70', H'01', H'BA', H'EB', H'9C', H'F8', H'40', H'CA', H'E9', H'C4', H'02', H'CA', H'E8', H'3F', H'C2', H'E9'
	DW	H'35', H'C2', H'E8', H'31', H'3F', H'35', H'01', H'40', H'35', H'40', H'1C', H'1C', H'1C', H'1C', H'CA', H'F6'
	DW	H'3F', H'C2', H'E9', H'35', H'C2', H'E8', H'31', H'C4', H'0D', H'C9', H'FF', H'C4', H'FF', H'C9', H'00', H'C9'
	DW	H'01', H'3F', H'C2', H'E9', H'35', H'C2', H'E8', H'31', H'C1', H'00', H'E4', H'FF', H'94', H'12', H'03', H'C1'
	DW	H'01', H'FA', H'EF', H'C1', H'00', H'FA', H'EE', H'94', H'07', H'C1', H'02', H'01', H'C5', H'80', H'90', H'E8'
	DW	H'31', H'CA', H'F3', H'31', H'35', H'CA', H'F2', H'35', H'C2', H'EF', H'E1', H'01', H'9C', H'07', H'C2', H'EE'
	DW	H'E1', H'00', H'9C', H'01', H'3F', H'C2', H'F2', H'DC', H'80', H'CA', H'F2', H'3F', H'02', H'0C', H'07', H'56'
	DW	H'2C', H'25', H'8D', H'4C', H'1E', H'06', H'AB', H'0C', H'35', H'0B', H'97', H'06', H'30', H'09', H'15', H'0B'
	DW	H'E1', H'08', H'23', H'4C', H'1E', H'2C', H'51', H'4C', H'49', H'53', H'D4', H'0B', H'97', H'06', H'AB', H'0C'
	DW	H'47', H'09', H'15', H'0B', H'E1', H'4C', H'49', H'0B', H'BD', H'02', H'D8', H'8F', H'2F', H'03', H'05', H'4C'
	DW	H'1C', H'2C', H'60', H'52', H'55', H'CE', H'01', H'2F', H'0B', H'97', H'0B', H'BD', H'02', H'BF', H'02', H'83'
	DW	H'2C', H'6D', H'43', H'4C', H'45', H'41', H'D2', H'01', H'2F', H'00', H'50', H'02', H'83', H'2C', H'86', H'4E'
	DW	H'45', H'D7', H'06', H'AB', H'0C', H'78', H'4C', H'7A', H'0A', H'33', H'01', H'2F', H'09', H'15', H'0B', H'8C'
	DW	H'0B', H'97', H'0B', H'D0', H'02', H'83', H'2C', H'8B', H'4C', H'45', H'D4', H'04', H'E0', H'0C', H'9A', H'2E'
	DW	H'2F', H'BD', H'8E', H'35', H'04', H'C0', H'01', H'2F', H'02', H'83', H'2C', H'AA', H'C0', H'8E', H'AC', H'2E'
	DW	H'2F', H'BD', H'8E', H'35', H'08', H'07', H'01', H'2F', H'02', H'83', H'2C', H'BC', H'49', H'C6', H'8E', H'35'
	DW	H'2C', H'B6', H'54', H'48', H'45', H'CE', H'09', H'15', H'05', H'D0', H'4C', H'86', H'2C', H'D1', H'55', H'4E'
	DW	H'54', H'49', H'CC', H'06', H'3B', H'8E', H'35', H'01', H'2F', H'09', H'15', H'09', H'27', H'0B', H'C4', H'02'
	DW	H'83', H'2C', H'DD', H'44', H'CF', H'06', H'3B', H'01', H'2F', H'09', H'77', H'02', H'83', H'2D', H'00', H'47'
	DW	H'CF', H'2C', H'EB', H'54', H'CF', H'8E', H'35', H'01', H'2F', H'4C', H'F6', H'2E', H'2F', H'53', H'55', H'C2'
	DW	H'8E', H'35', H'01', H'2F', H'01', H'09', H'0B', H'97', H'09', H'15', H'0B', H'E1', H'01', H'68', H'02', H'83'
	DW	H'2D', H'10', H'52', H'45', H'54', H'55', H'52', H'CE', H'01', H'2F', H'01', H'42', H'0B', H'C4', H'02', H'83'
	DW	H'2D', H'2A', H'4E', H'45', H'58', H'D4', H'06', H'3B', H'04', H'E0', H'0E', H'2F', H'01', H'2F', H'0A', H'88'
	DW	H'8E', H'5F', H'09', H'15', H'0A', H'ED', H'0B', H'C4', H'02', H'83', H'2D', H'54', H'46', H'4F', H'D2', H'06'
	DW	H'3B', H'04', H'E0', H'0E', H'2F', H'2E', H'2F', H'BD', H'8E', H'35', H'2E', H'2F', H'54', H'CF', H'8E', H'35'
	DW	H'2D', H'4A', H'53', H'54', H'45', H'D0', H'8E', H'35', H'4D', H'4C', H'0A', H'33', H'01', H'2F', H'0A', H'45'
	DW	H'04', H'C0', H'02', H'83', H'2D', H'67', H'53', H'54', H'41', H'D4', H'2E', H'2F', H'BD', H'8E', H'35', H'09'
	DW	H'15', H'09', H'4C', H'01', H'2F', H'02', H'83', H'2D', H'7E', H'50', H'41', H'47', H'C5', H'2E', H'2F', H'BD'
	DW	H'8E', H'35', H'01', H'2F', H'09', H'15', H'0B', H'8C', H'0B', H'97', H'0B', H'BD', H'02', H'83', H'2D', H'9E'
	DW	H'A4', H'8E', H'AC', H'2E', H'2F', H'BD', H'2D', H'8F', H'A2', H'09', H'15', H'0B', H'35', H'4D', H'9A', H'2E'
	DW	H'2F', H'A4', H'8E', H'AC', H'06', H'30', H'0B', H'55', H'06', H'30', H'01', H'2F', H'02', H'83', H'2D', H'D1'
	DW	H'50', H'D2', H'2D', H'A7', H'49', H'4E', H'D4', H'2D', H'AE', H'A2', H'01', H'75', H'4D', H'C1', H'2D', H'BD'
	DW	H'A4', H'8E', H'AC', H'06', H'30', H'09', H'15', H'0B', H'09', H'06', H'30', H'4D', H'C1', H'8E', H'35', H'8F'
	DW	H'2F', H'2D', H'C6', H'AC', H'4D', H'A7', H'2D', H'CB', H'BB', H'4D', H'CD', H'02', H'0C', H'01', H'2F', H'02'
	DW	H'83', H'2E', H'09', H'49', H'4E', H'50', H'55', H'D4', H'06', H'3B', H'04', H'E0', H'0D', H'F6', H'06', H'30'
	DW	H'07', H'56', H'8E', H'35', H'04', H'C0', H'06', H'30', H'2E', H'05', H'AC', H'04', H'E0', H'0E', H'2F', H'06'
	DW	H'30', H'2E', H'2F', H'AC', H'4D', H'E2', H'2E', H'2F', H'A4', H'8E', H'AC', H'06', H'30', H'07', H'56', H'09'
	DW	H'15', H'0B', H'25', H'06', H'30', H'01', H'2F', H'02', H'83', H'2E', H'12', H'45', H'4E', H'C4', H'01', H'2F'
	DW	H'02', H'7F', H'2E', H'26', H'4C', H'49', H'4E', H'CB', H'8E', H'35', H'01', H'2F', H'06', H'30', H'09', H'15'
	DW	H'09', H'66', H'06', H'30', H'02', H'83', H'2E', H'2F', H'52', H'45', H'CD', H'09', H'B8', H'02', H'83', H'02'
	DW	H'1A', H'8F', H'2F', H'02', H'A9', H'8E', H'61', H'2E', H'3E', H'BD', H'8E', H'61', H'05', H'43', H'2E', H'53'
	DW	H'BC', H'2E', H'48', H'BD', H'8E', H'61', H'05', H'4F', H'2E', H'4F', H'BE', H'8E', H'61', H'05', H'47', H'8E'
	DW	H'61', H'05', H'4B', H'2E', H'8B', H'BE', H'2E', H'5D', H'BD', H'8E', H'61', H'05', H'57', H'8E', H'61', H'05'
	DW	H'53', H'2E', H'6A', H'AD', H'8E', H'8D', H'03', H'5A', H'4E', H'6F', H'2E', H'6D', H'AB', H'8E', H'8D', H'2E'
	DW	H'78', H'AB', H'8E', H'8D', H'03', H'2C', H'4E', H'6F', H'2E', H'81', H'AD', H'8E', H'8D', H'03', H'43', H'4E'
	DW	H'6F', H'2E', H'8B', H'4F', H'D2', H'8E', H'8D', H'05', H'EB', H'4E', H'6F', H'00', H'F5', H'8E', H'AC', H'2E'
	DW	H'98', H'AA', H'8E', H'AC', H'03', H'71', H'4E', H'8F', H'2E', H'A1', H'AF', H'8E', H'AC', H'04', H'07', H'4E'
	DW	H'8F', H'2E', H'8B', H'41', H'4E', H'C4', H'8E', H'AC', H'05', H'E7', H'4E', H'8F', H'04', H'E0', H'0E', H'B4'
	DW	H'05', H'2B', H'00', H'F5', H'06', H'AB', H'0E', H'BA', H'00', H'F5', H'2E', H'C1', H'A3', H'06', H'4B', H'00'
	DW	H'F5', H'2E', H'CB', H'A8', H'8E', H'35', H'2E', H'2F', H'A9', H'00', H'F5', H'2E', H'D4', H'C0', H'8E', H'AC'
	DW	H'07', H'E9', H'00', H'F5', H'2E', H'DF', H'4E', H'4F', H'D4', H'8E', H'AC', H'05', H'EF', H'00', H'F5', H'2E'
	DW	H'E9', H'53', H'54', H'41', H'D4', H'09', H'55', H'00', H'F5', H'2E', H'F4', H'54', H'4F', H'D0', H'0B', H'97'
	DW	H'09', H'93', H'00', H'F5', H'2F', H'01', H'4D', H'4F', H'C4', H'8F', H'20', H'04', H'07', H'09', H'BF', H'00'
	DW	H'F5', H'2F', H'16', H'52', H'4E', H'C4', H'8F', H'20', H'09', H'D1', H'03', H'43', H'03', H'2C', H'04', H'07'
	DW	H'09', H'BF', H'03', H'2C', H'00', H'F5', H'2E', H'2F', H'50', H'41', H'47', H'C5', H'0B', H'7A', H'00', H'F5'
	DW	H'2E', H'2F', H'A8', H'8E', H'35', H'2E', H'2F', H'AC', H'8E', H'35', H'2E', H'2F', H'A9', H'00', H'F5', H'06'
	DW	H'30', H'01', H'8E', H'04', H'07', H'01', H'C5', H'06', H'30', H'00', H'F5', H'20', H'45', H'52', H'52', H'4F'
	DW	H'D2', H'41', H'52', H'45', H'C1', H'53', H'54', H'4D', H'D4', H'43', H'48', H'41', H'D2', H'53', H'4E', H'54'
	DW	H'D8', H'56', H'41', H'4C', H'D5', H'45', H'4E', H'44', H'A2', H'4E', H'4F', H'47', H'CF', H'52', H'54', H'52'
	DW	H'CE', H'4E', H'45', H'53', H'D4', H'4E', H'45', H'58', H'D4', H'46', H'4F', H'D2', H'44', H'49', H'56', H'B0'
	DW	H'42', H'52', H'CB', H'55', H'4E', H'54', H'CC', H'C4', H'08', H'CA', H'EB', H'06', H'DC', H'02', H'07', H'06'
	DW	H'D4', H'20', H'9C', H'FB', H'C4', H'57', H'8F', H'04', H'06', H'D4', H'20', H'9C', H'F2', H'06', H'D4', H'FD'
	DW	H'DC', H'01', H'07', H'C4', H'85', H'8F', H'08', H'06', H'D4', H'20', H'98', H'04', H'C4', H'01', H'90', H'04'
	DW	H'C4', H'00', H'9C', H'00', H'CA', H'EA', H'1F', H'01', H'1D', H'01', H'06', H'DC', H'01', H'E2', H'EA', H'07'
	DW	H'BA', H'EB', H'9C', H'DF', H'06', H'D4', H'FE', H'07', H'8F', H'08', H'40', H'D4', H'7F', H'01', H'40', H'3F'
	DW	H'90', H'B5', H'01', H'C4', H'FF', H'8F', H'17', H'06', H'DC', H'01', H'07', H'C4', H'09', H'CA', H'E8', H'C4'
	DW	H'8A', H'8F', H'08', H'BA', H'E8', H'98', H'10', H'40', H'D4', H'01', H'CA', H'E9', H'01', H'1C', H'01', H'06'
	DW	H'DC', H'01', H'E2', H'E9', H'07', H'90', H'E8', H'06', H'D4', H'FE', H'07', H'3F', H'90', H'D4', H'00', H'00'
	DW	H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00', H'00'

	END
